bcmaps: bcmaps: A data package providing various map layers for British Columbia
Description
Various layers of B.C., including administrative boundaries, natural
resource management boundaries, etc. All layers are available as sp objects,
and are in BC Albers
projection, which is the
B.C. government standard.
The layers are sourced from various places under open licenses, including
DataBC, the Governmment of Canada
Open Data Portal, and
Statistics Canada.
Each layer's help page contians a section describing the source for the data.